"""
Generated class for ImplementationGuide. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.ContactDetail import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.UsageContext import *


class DependsOn(FhirBaseModel):
    """Another implementation guide that this implementation depends on. Typically, an implementation guide uses value sets, profiles etc.defined in other implementation guides.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str uri: Identity of the IG that this depends on
    :param str packageId: NPM Package name for IG this depends on
    :param str version: Version of the IG
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        uri: "str" = None,
        packageId: "str" = None,
        version: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.uri = uri
        self.packageId = packageId
        self.version = version

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class _global(FhirBaseModel):
    """A set of profiles that all resources covered by this implementation guide must conform to.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: Type this profile applies to
    :param str profile: Profile that all resources must conform to
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        profile: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.profile = profile

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Grouping(FhirBaseModel):
    """A logical group of resources. Logical groups can be used when building pages.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: Descriptive name for the package
    :param str description: Human readable text describing the package
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        description: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.description = description

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Resource(FhirBaseModel):
    """A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference reference: Location of the resource
    :param str fhirVersion: Versions this applies to (if different to IG)
    :param str name: Human Name for the resource
    :param str description: Reason why included in guide
    :param bool exampleBoolean: Is an example/What is this an example of?
    :param str exampleCanonical: Is an example/What is this an example of?
    :param str groupingId: Grouping this is part of
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        reference: "Reference" = None,
        fhirVersion: list["str"] = None,
        name: "str" = None,
        description: "str" = None,
        exampleBoolean: "bool" = None,
        exampleCanonical: "str" = None,
        groupingId: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.reference = reference
        self.fhirVersion = fhirVersion or []
        self.name = name
        self.description = description
        self.exampleBoolean = exampleBoolean
        self.exampleCanonical = exampleCanonical
        self.groupingId = groupingId

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Page(FhirBaseModel):
    """A page / section in the implementation guide. The root page is the implementation guide home page.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str nameUrl: Where to find that page
    :param Reference nameReference: Where to find that page
    :param str title: Short title shown for navigational assistance
    :param str generation: html | markdown | xml | generated
    :param Page page: Nested Pages / Sections
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "nameReference": {"class_name": "Reference", "is_contained": False},
        "page": {"class_name": "Page", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        nameUrl: "str" = None,
        nameReference: "Reference" = None,
        title: "str" = None,
        generation: "str" = None,
        page: list["Page"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.nameUrl = nameUrl
        self.nameReference = nameReference
        self.title = title
        self.generation = generation
        self.page = page or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Parameter(FhirBaseModel):
    """Defines how IG is built by tools.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: apply | path-resource | path-pages | path-tx-cache | expansion-parameter | rule-broken-links | generate-xml | generate-json | generate-turtle | html-template
    :param str value: Value for named type
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        value: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.value = value

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Template(FhirBaseModel):
    """A template for building resources.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str code: Type of template specified
    :param str source: The source location for the template
    :param str scope: The scope in which the template applies
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "str" = None,
        source: "str" = None,
        scope: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.source = source
        self.scope = scope

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Definition(FhirBaseModel):
    """The information needed by an IG publisher tool to publish the whole implementation guide.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Grouping grouping: Grouping used to present related resources in the IG
    :param Resource resource: Resource in the implementation guide
    :param Page page: Page/Section in the Guide
    :param Parameter parameter: Defines how IG is built by tools
    :param Template template: A template for building resources
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "grouping": {"class_name": "Grouping", "is_contained": True},
        "resource": {"class_name": "Resource", "is_contained": True},
        "page": {"class_name": "Page", "is_contained": True},
        "parameter": {"class_name": "Parameter", "is_contained": True},
        "template": {"class_name": "Template", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        grouping: list["Grouping"] = None,
        resource: list["Resource"] = None,
        page: "Page" = None,
        parameter: list["Parameter"] = None,
        template: list["Template"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.grouping = grouping or []
        self.resource = resource or []
        self.page = page
        self.parameter = parameter or []
        self.template = template or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Resource(FhirBaseModel):
    """A resource that is part of the implementation guide. Conformance resources (value set, structure definition, capability statements etc.) are obvious candidates for inclusion, but any kind of resource can be included as an example resource.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference reference: Location of the resource
    :param bool exampleBoolean: Is an example/What is this an example of?
    :param str exampleCanonical: Is an example/What is this an example of?
    :param str relativePath: Relative path for page in IG
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        reference: "Reference" = None,
        exampleBoolean: "bool" = None,
        exampleCanonical: "str" = None,
        relativePath: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.reference = reference
        self.exampleBoolean = exampleBoolean
        self.exampleCanonical = exampleCanonical
        self.relativePath = relativePath

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Page(FhirBaseModel):
    """Information about a page within the IG.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str name: HTML page name
    :param str title: Title of the page, for references
    :param str anchor: Anchor available on the page
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        name: "str" = None,
        title: "str" = None,
        anchor: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.name = name
        self.title = title
        self.anchor = anchor or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Manifest(FhirBaseModel):
    """Information about an assembled implementation guide, created by the publication tooling.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str rendering: Location of rendered implementation guide
    :param Resource resource: Resource in the implementation guide
    :param Page page: HTML page within the parent IG
    :param str image: Image within the IG
    :param str other: Additional linkable file in IG
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "resource": {"class_name": "Resource", "is_contained": True},
        "page": {"class_name": "Page", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        rendering: "str" = None,
        resource: list["Resource"] = None,
        page: list["Page"] = None,
        image: list["str"] = None,
        other: list["str"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.rendering = rendering
        self.resource = resource or []
        self.page = page or []
        self.image = image or []
        self.other = other or []

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ImplementationGuide(DomainResource):
    """A set of rules of how a particular interoperability or standards problem is solved - typically through the use of FHIR resources. This resource is used to gather all the parts of an implementation guide into a logical whole and to publish a computable definition of all the parts.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this implementation guide, represented as a URI (globally unique)
    :param str version: Business version of the implementation guide
    :param str name: Name for this implementation guide (computer friendly)
    :param str title: Name for this implementation guide (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the implementation guide
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for implementation guide (if applicable)
    :param str copyright: Use and/or publishing restrictions
    :param str packageId: NPM Package name for IG
    :param str license: SPDX license code for this IG (or not-open-source)
    :param str fhirVersion: FHIR Version(s) this Implementation Guide targets
    :param DependsOn dependsOn: Another Implementation guide this depends on
    :param _global _global: Profiles that apply globally
    :param Definition definition: Information needed to build the IG
    :param Manifest manifest: Information about an assembled IG
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "dependsOn": {"class_name": "DependsOn", "is_contained": True},
        "_global": {"class_name": "_global", "is_contained": True},
        "definition": {"class_name": "Definition", "is_contained": True},
        "manifest": {"class_name": "Manifest", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        copyright: "str" = None,
        packageId: "str" = None,
        license: "str" = None,
        fhirVersion: list["str"] = None,
        dependsOn: list["DependsOn"] = None,
        _global: list["_global"] = None,
        definition: "Definition" = None,
        manifest: "Manifest" = None,
    ):

        self.resourceType = "ImplementationGuide"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.version = version
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.copyright = copyright
        self.packageId = packageId
        self.license = license
        self.fhirVersion = fhirVersion or []
        self.dependsOn = dependsOn or []
        self._global = _global or []
        self.definition = definition
        self.manifest = manifest

    @classmethod
    def from_dict(cls, data: dict) -> "ImplementationGuide":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ImplementationGuide":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Requirements. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Statement(FhirBaseModel):
    """The actual statement of requirement, in markdown format.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str key: Key that identifies this statement
    :param str label: Short Human label for this statement
    :param str conformance: SHALL | SHOULD | MAY | SHOULD-NOT
    :param bool conditionality: Set to true if requirements statement is conditional
    :param str requirement: The actual requirement
    :param str derivedFrom: Another statement this clarifies/restricts ([url#]key)
    :param str parent: A larger requirement that this requirement helps to refine and enable
    :param str satisfiedBy: Design artifact that satisfies this requirement
    :param str reference: External artifact (rule/document etc. that) created this requirement
    :param Reference source: Who asked for this statement
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "source": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        key: "str" = None,
        label: "str" = None,
        conformance: list["str"] = None,
        conditionality: "bool" = None,
        requirement: "str" = None,
        derivedFrom: "str" = None,
        parent: "str" = None,
        satisfiedBy: list["str"] = None,
        reference: list["str"] = None,
        source: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.key = key
        self.label = label
        self.conformance = conformance or []
        self.conditionality = conditionality
        self.requirement = requirement
        self.derivedFrom = derivedFrom
        self.parent = parent
        self.satisfiedBy = satisfiedBy or []
        self.reference = reference or []
        self.source = source or []

    @classmethod
    def from_dict(cls, data: dict) -> "Requirements":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Requirements":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Requirements(DomainResource):
    """The Requirements resource is used to describe an actor - a human or an application that plays a role in data exchange, and that may have obligations associated with the role the actor plays.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this Requirements, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the Requirements (business identifier)
    :param str version: Business version of the Requirements
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this Requirements (computer friendly)
    :param str title: Name for this Requirements (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the requirements
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for Requirements (if applicable)
    :param str purpose: Why this Requirements is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param str derivedFrom: Other set of Requirements this builds on
    :param str reference: External artifact (rule/document etc. that) created this set of requirements
    :param str actor: Actor for these requirements
    :param Statement statement: Actual statement as markdown
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "statement": {"class_name": "Statement", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        derivedFrom: list["str"] = None,
        reference: list["str"] = None,
        actor: list["str"] = None,
        statement: list["Statement"] = None,
    ):

        self.resourceType = "Requirements"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.derivedFrom = derivedFrom or []
        self.reference = reference or []
        self.actor = actor or []
        self.statement = statement or []

    @classmethod
    def from_dict(cls, data: dict) -> "Requirements":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Requirements":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicationRequest. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Annotation import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Dosage import *
from fhirmodels.R5.Duration import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Quantity import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class InitialFill(FhirBaseModel):
    """Indicates the quantity or duration for the first dispense of the medication.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity quantity: First fill quantity
    :param Duration duration: First fill duration
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "duration": {"class_name": "Duration", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        quantity: "Quantity" = None,
        duration: "Duration" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.quantity = quantity
        self.duration = duration

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DispenseRequest(FhirBaseModel):
    """Indicates the specific details for the dispense or medication supply part of a medication request (also known as a Medication Prescription or Medication Order).  Note that this information is not always sent with the order.  There may be in some settings (e.g. hospitals) institutional or system support for completing the dispense details in the pharmacy department.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param InitialFill initialFill: First fill details
    :param Duration dispenseInterval: Minimum period of time between dispenses
    :param Period validityPeriod: Time period supply is authorized for
    :param int numberOfRepeatsAllowed: Number of refills authorized
    :param Quantity quantity: Amount of medication to supply per dispense
    :param Duration expectedSupplyDuration: Number of days supply per dispense
    :param Reference dispenser: Intended performer of dispense
    :param Annotation dispenserInstruction: Additional information for the dispenser
    :param CodeableConcept doseAdministrationAid: Type of adherence packaging to use for the dispense
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "initialFill": {"class_name": "InitialFill", "is_contained": True},
        "dispenseInterval": {"class_name": "Duration", "is_contained": False},
        "validityPeriod": {"class_name": "Period", "is_contained": False},
        "quantity": {"class_name": "Quantity", "is_contained": False},
        "expectedSupplyDuration": {"class_name": "Duration", "is_contained": False},
        "dispenser": {"class_name": "Reference", "is_contained": False},
        "dispenserInstruction": {"class_name": "Annotation", "is_contained": False},
        "doseAdministrationAid": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        initialFill: "InitialFill" = None,
        dispenseInterval: "Duration" = None,
        validityPeriod: "Period" = None,
        numberOfRepeatsAllowed: "int" = None,
        quantity: "Quantity" = None,
        expectedSupplyDuration: "Duration" = None,
        dispenser: "Reference" = None,
        dispenserInstruction: list["Annotation"] = None,
        doseAdministrationAid: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.initialFill = initialFill
        self.dispenseInterval = dispenseInterval
        self.validityPeriod = validityPeriod
        self.numberOfRepeatsAllowed = numberOfRepeatsAllowed
        self.quantity = quantity
        self.expectedSupplyDuration = expectedSupplyDuration
        self.dispenser = dispenser
        self.dispenserInstruction = dispenserInstruction or []
        self.doseAdministrationAid = doseAdministrationAid

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Substitution(FhirBaseModel):
    """Indicates whether or not substitution can or should be part of the dispense. In some cases, substitution must happen, in other cases substitution must not happen. This block explains the prescriber's intent. If nothing is specified substitution may be done.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param bool allowedBoolean: Whether substitution is allowed or not
    :param CodeableConcept allowedCodeableConcept: Whether substitution is allowed or not
    :param CodeableConcept reason: Why should (not) substitution be made
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "allowedCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "reason": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        allowedBoolean: "bool" = None,
        allowedCodeableConcept: "CodeableConcept" = None,
        reason: "CodeableConcept" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.allowedBoolean = allowedBoolean
        self.allowedCodeableConcept = allowedCodeableConcept
        self.reason = reason

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicationRequest(DomainResource):
    """An order or request for both supply of the medication and the instructions for administration of the medication to a patient. The resource is called "MedicationRequest" rather than "MedicationPrescription" or "MedicationOrder" to generalize the use across inpatient and outpatient settings, including care plans, etc., and to harmonize with workflow patterns.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External ids for this request
    :param Reference basedOn: A plan or request that is fulfilled in whole or in part by this medication request
    :param Reference priorPrescription: Reference to an order/prescription that is being replaced by this MedicationRequest
    :param Identifier groupIdentifier: Composite request this is part of
    :param str status: active | on-hold | ended | stopped | completed | cancelled | entered-in-error | draft | unknown
    :param CodeableConcept statusReason: Reason for current status
    :param str statusChanged: When the status was changed
    :param str intent: proposal | plan | order | original-order | reflex-order | filler-order | instance-order | option
    :param CodeableConcept category: Grouping or category of medication request
    :param str priority: routine | urgent | asap | stat
    :param bool doNotPerform: True if patient is to stop taking or not to start taking the medication
    :param CodeableReference medication: Medication to be taken
    :param Reference subject: Individual or group for whom the medication has been requested
    :param Reference informationSource: The person or organization who provided the information about this request, if the source is someone other than the requestor
    :param Reference encounter: Encounter created as part of encounter/admission/stay
    :param Reference supportingInformation: Information to support fulfilling of the medication
    :param str authoredOn: When request was initially authored
    :param Reference requester: Who/What requested the Request
    :param bool reported: Reported rather than primary record
    :param CodeableConcept performerType: Desired kind of performer of the medication administration
    :param Reference performer: Intended performer of administration
    :param CodeableReference device: Intended type of device for the administration
    :param Reference recorder: Person who entered the request
    :param CodeableReference reason: Reason or indication for ordering or not ordering the medication
    :param CodeableConcept courseOfTherapyType: Overall pattern of medication administration
    :param Reference insurance: Associated insurance coverage
    :param Annotation note: Information about the prescription
    :param str renderedDosageInstruction: Full representation of the dosage instructions
    :param Period effectiveDosePeriod: Period over which the medication is to be taken
    :param Dosage dosageInstruction: Specific instructions for how the medication should be taken
    :param DispenseRequest dispenseRequest: Medication supply authorization
    :param Substitution substitution: Any restrictions on medication substitution
    :param Reference eventHistory: A list of events of interest in the lifecycle
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "priorPrescription": {"class_name": "Reference", "is_contained": False},
        "groupIdentifier": {"class_name": "Identifier", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "medication": {"class_name": "CodeableReference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "informationSource": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "supportingInformation": {"class_name": "Reference", "is_contained": False},
        "requester": {"class_name": "Reference", "is_contained": False},
        "performerType": {"class_name": "CodeableConcept", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "device": {"class_name": "CodeableReference", "is_contained": False},
        "recorder": {"class_name": "Reference", "is_contained": False},
        "reason": {"class_name": "CodeableReference", "is_contained": False},
        "courseOfTherapyType": {"class_name": "CodeableConcept", "is_contained": False},
        "insurance": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "effectiveDosePeriod": {"class_name": "Period", "is_contained": False},
        "dosageInstruction": {"class_name": "Dosage", "is_contained": False},
        "dispenseRequest": {"class_name": "DispenseRequest", "is_contained": True},
        "substitution": {"class_name": "Substitution", "is_contained": True},
        "eventHistory": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        priorPrescription: "Reference" = None,
        groupIdentifier: "Identifier" = None,
        status: "str" = None,
        statusReason: "CodeableConcept" = None,
        statusChanged: "str" = None,
        intent: "str" = None,
        category: list["CodeableConcept"] = None,
        priority: "str" = None,
        doNotPerform: "bool" = None,
        medication: "CodeableReference" = None,
        subject: "Reference" = None,
        informationSource: list["Reference"] = None,
        encounter: "Reference" = None,
        supportingInformation: list["Reference"] = None,
        authoredOn: "str" = None,
        requester: "Reference" = None,
        reported: "bool" = None,
        performerType: "CodeableConcept" = None,
        performer: list["Reference"] = None,
        device: list["CodeableReference"] = None,
        recorder: "Reference" = None,
        reason: list["CodeableReference"] = None,
        courseOfTherapyType: "CodeableConcept" = None,
        insurance: list["Reference"] = None,
        note: list["Annotation"] = None,
        renderedDosageInstruction: "str" = None,
        effectiveDosePeriod: "Period" = None,
        dosageInstruction: list["Dosage"] = None,
        dispenseRequest: "DispenseRequest" = None,
        substitution: "Substitution" = None,
        eventHistory: list["Reference"] = None,
    ):

        self.resourceType = "MedicationRequest"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.priorPrescription = priorPrescription
        self.groupIdentifier = groupIdentifier
        self.status = status
        self.statusReason = statusReason
        self.statusChanged = statusChanged
        self.intent = intent
        self.category = category or []
        self.priority = priority
        self.doNotPerform = doNotPerform
        self.medication = medication
        self.subject = subject
        self.informationSource = informationSource or []
        self.encounter = encounter
        self.supportingInformation = supportingInformation or []
        self.authoredOn = authoredOn
        self.requester = requester
        self.reported = reported
        self.performerType = performerType
        self.performer = performer or []
        self.device = device or []
        self.recorder = recorder
        self.reason = reason or []
        self.courseOfTherapyType = courseOfTherapyType
        self.insurance = insurance or []
        self.note = note or []
        self.renderedDosageInstruction = renderedDosageInstruction
        self.effectiveDosePeriod = effectiveDosePeriod
        self.dosageInstruction = dosageInstruction or []
        self.dispenseRequest = dispenseRequest
        self.substitution = substitution
        self.eventHistory = eventHistory or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for EffectEvidenceSynthesis. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.ContactDetail import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.RelatedArtifact import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.UsageContext import *


class SampleSize(FhirBaseModel):
    """A description of the size of the sample involved in the synthesis.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of sample size
    :param int numberOfStudies: How many studies?
    :param int numberOfParticipants: How many participants?
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        numberOfStudies: "int" = None,
        numberOfParticipants: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.numberOfStudies = numberOfStudies
        self.numberOfParticipants = numberOfParticipants

    @classmethod
    def from_dict(cls, data: dict) -> "EffectEvidenceSynthesis":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EffectEvidenceSynthesis":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ResultsByExposure(FhirBaseModel):
    """A description of the results for each exposure considered in the effect estimate.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of results by exposure
    :param str exposureState: exposure | exposure-alternative
    :param CodeableConcept variantState: Variant exposure states
    :param Reference riskEvidenceSynthesis: Risk evidence synthesis
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "variantState": {"class_name": "CodeableConcept", "is_contained": False},
        "riskEvidenceSynthesis": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        exposureState: "str" = None,
        variantState: "CodeableConcept" = None,
        riskEvidenceSynthesis: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.exposureState = exposureState
        self.variantState = variantState
        self.riskEvidenceSynthesis = riskEvidenceSynthesis

    @classmethod
    def from_dict(cls, data: dict) -> "EffectEvidenceSynthesis":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EffectEvidenceSynthesis":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class PrecisionEstimate(FhirBaseModel):
    """A description of the precision of the estimate for the effect.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Type of precision estimate
    :param float level: Level of confidence interval
    :param float _from: Lower bound
    :param float to: Upper bound
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        level: "float" = None,
        _from: "float" = None,
        to: "float" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.level = level
        self._from = _from
        self.to = to

    @classmethod
    def from_dict(cls, data: dict) -> "EffectEvidenceSynthesis":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EffectEvidenceSynthesis":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class EffectEstimate(FhirBaseModel):
    """The estimated effect of the exposure variant.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of effect estimate
    :param CodeableConcept type: Type of efffect estimate
    :param CodeableConcept variantState: Variant exposure states
    :param float value: Point estimate
    :param CodeableConcept unitOfMeasure: What unit is the outcome described in?
    :param PrecisionEstimate precisionEstimate: How precise the estimate is
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "variantState": {"class_name": "CodeableConcept", "is_contained": False},
        "unitOfMeasure": {"class_name": "CodeableConcept", "is_contained": False},
        "precisionEstimate": {"class_name": "PrecisionEstimate", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        type: "CodeableConcept" = None,
        variantState: "CodeableConcept" = None,
        value: "float" = None,
        unitOfMeasure: "CodeableConcept" = None,
        precisionEstimate: list["PrecisionEstimate"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.type = type
        self.variantState = variantState
        self.value = value
        self.unitOfMeasure = unitOfMeasure
        self.precisionEstimate = precisionEstimate or []

    @classmethod
    def from_dict(cls, data: dict) -> "EffectEvidenceSynthesis":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EffectEvidenceSynthesis":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class CertaintySubcomponent(FhirBaseModel):
    """A description of a component of the overall certainty.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Type of subcomponent of certainty rating
    :param CodeableConcept rating: Subcomponent certainty rating
    :param Annotation note: Used for footnotes or explanatory notes
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "rating": {"class_name": "CodeableConcept", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "CodeableConcept" = None,
        rating: list["CodeableConcept"] = None,
        note: list["Annotation"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.rating = rating or []
        self.note = note or []

    @classmethod
    def from_dict(cls, data: dict) -> "EffectEvidenceSynthesis":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EffectEvidenceSynthesis":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Certainty(FhirBaseModel):
    """A description of the certainty of the effect estimate.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept rating: Certainty rating
    :param Annotation note: Used for footnotes or explanatory notes
    :param CertaintySubcomponent certaintySubcomponent: A component that contributes to the overall certainty
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "rating": {"class_name": "CodeableConcept", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "certaintySubcomponent": {
            "class_name": "CertaintySubcomponent",
            "is_contained": True,
        },
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        rating: list["CodeableConcept"] = None,
        note: list["Annotation"] = None,
        certaintySubcomponent: list["CertaintySubcomponent"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.rating = rating or []
        self.note = note or []
        self.certaintySubcomponent = certaintySubcomponent or []

    @classmethod
    def from_dict(cls, data: dict) -> "EffectEvidenceSynthesis":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EffectEvidenceSynthesis":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class EffectEvidenceSynthesis(DomainResource):
    """The EffectEvidenceSynthesis resource describes the difference in an outcome between exposures states in a population where the effect estimate is derived from a combination of research studies.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this effect evidence synthesis, represented as a URI (globally unique)
    :param Identifier identifier: Additional identifier for the effect evidence synthesis
    :param str version: Business version of the effect evidence synthesis
    :param str name: Name for this effect evidence synthesis (computer friendly)
    :param str title: Name for this effect evidence synthesis (human friendly)
    :param str status: draft | active | retired | unknown
    :param str date: Date last changed
    :param str publisher: Name of the publisher (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the effect evidence synthesis
    :param Annotation note: Used for footnotes or explanatory notes
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction for effect evidence synthesis (if applicable)
    :param str copyright: Use and/or publishing restrictions
    :param str approvalDate: When the effect evidence synthesis was approved by publisher
    :param str lastReviewDate: When the effect evidence synthesis was last reviewed
    :param Period effectivePeriod: When the effect evidence synthesis is expected to be used
    :param CodeableConcept topic: The category of the EffectEvidenceSynthesis, such as Education, Treatment, Assessment, etc.
    :param ContactDetail author: Who authored the content
    :param ContactDetail editor: Who edited the content
    :param ContactDetail reviewer: Who reviewed the content
    :param ContactDetail endorser: Who endorsed the content
    :param RelatedArtifact relatedArtifact: Additional documentation, citations, etc.
    :param CodeableConcept synthesisType: Type of synthesis
    :param CodeableConcept studyType: Type of study
    :param Reference population: What population?
    :param Reference exposure: What exposure?
    :param Reference exposureAlternative: What comparison exposure?
    :param Reference outcome: What outcome?
    :param SampleSize sampleSize: What sample size was involved?
    :param ResultsByExposure resultsByExposure: What was the result per exposure?
    :param EffectEstimate effectEstimate: What was the estimated effect
    :param Certainty certainty: How certain is the effect
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "topic": {"class_name": "CodeableConcept", "is_contained": False},
        "author": {"class_name": "ContactDetail", "is_contained": False},
        "editor": {"class_name": "ContactDetail", "is_contained": False},
        "reviewer": {"class_name": "ContactDetail", "is_contained": False},
        "endorser": {"class_name": "ContactDetail", "is_contained": False},
        "relatedArtifact": {"class_name": "RelatedArtifact", "is_contained": False},
        "synthesisType": {"class_name": "CodeableConcept", "is_contained": False},
        "studyType": {"class_name": "CodeableConcept", "is_contained": False},
        "population": {"class_name": "Reference", "is_contained": False},
        "exposure": {"class_name": "Reference", "is_contained": False},
        "exposureAlternative": {"class_name": "Reference", "is_contained": False},
        "outcome": {"class_name": "Reference", "is_contained": False},
        "sampleSize": {"class_name": "SampleSize", "is_contained": True},
        "resultsByExposure": {"class_name": "ResultsByExposure", "is_contained": True},
        "effectEstimate": {"class_name": "EffectEstimate", "is_contained": True},
        "certainty": {"class_name": "Certainty", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        note: list["Annotation"] = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        copyright: "str" = None,
        approvalDate: "str" = None,
        lastReviewDate: "str" = None,
        effectivePeriod: "Period" = None,
        topic: list["CodeableConcept"] = None,
        author: list["ContactDetail"] = None,
        editor: list["ContactDetail"] = None,
        reviewer: list["ContactDetail"] = None,
        endorser: list["ContactDetail"] = None,
        relatedArtifact: list["RelatedArtifact"] = None,
        synthesisType: "CodeableConcept" = None,
        studyType: "CodeableConcept" = None,
        population: "Reference" = None,
        exposure: "Reference" = None,
        exposureAlternative: "Reference" = None,
        outcome: "Reference" = None,
        sampleSize: "SampleSize" = None,
        resultsByExposure: list["ResultsByExposure"] = None,
        effectEstimate: list["EffectEstimate"] = None,
        certainty: list["Certainty"] = None,
    ):

        self.resourceType = "EffectEvidenceSynthesis"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.name = name
        self.title = title
        self.status = status
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.note = note or []
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.copyright = copyright
        self.approvalDate = approvalDate
        self.lastReviewDate = lastReviewDate
        self.effectivePeriod = effectivePeriod
        self.topic = topic or []
        self.author = author or []
        self.editor = editor or []
        self.reviewer = reviewer or []
        self.endorser = endorser or []
        self.relatedArtifact = relatedArtifact or []
        self.synthesisType = synthesisType
        self.studyType = studyType
        self.population = population
        self.exposure = exposure
        self.exposureAlternative = exposureAlternative
        self.outcome = outcome
        self.sampleSize = sampleSize
        self.resultsByExposure = resultsByExposure or []
        self.effectEstimate = effectEstimate or []
        self.certainty = certainty or []

    @classmethod
    def from_dict(cls, data: dict) -> "EffectEvidenceSynthesis":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "EffectEvidenceSynthesis":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



import logging
from typing import Literal

import click

from fhirmodels import constants as _c
from fhirmodels import fhir_package, generator

# Configure the logger
logger = logging.getLogger(__name__)
logging.basicConfig(
    level=logging.INFO,
    format="%(asctime)s - %(name)s - %(levelname)s - %(message)s",
)


@click.group()
def main():
    """
    This tool helps in generating FHIR models from specified FHIR packages.
    Use the available commands to interact with the tool.
    """
    pass


@main.command()
@click.option(
    "--version",
    "-v",
    default="R4",
    type=click.Choice(["R4", "R4B", "R5"]),
    help="FHIR version to generate models for. Options are: R4, R4B, R5. Defaults to R4.",
)
def generate(
    version: Literal["R4", "R4B", "R5"],
):
    """Generate models from FHIR packages.

    This command will generate model classes based on the specified FHIR version.
    """
    logger.info(f"Generating models for FHIR version: {version}")

    # Load the FHIR package
    package_loader = fhir_package.FhirPackageLoader()
    package = package_loader.load_from_version(fhir_version=version)

    # Generate model classes
    gen = generator.ModelGenerator(package=package)
    gen.generate_model_classes()
    logger.info("Model generation completed.")


if __name__ == "__main__":
    main()



"""
Generated class for Location. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.Address import *
from fhirmodels.R5.Availability import *
from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.ExtendedContactDetail import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.VirtualServiceDetail import *


class Position(FhirBaseModel):
    """The absolute geographic location of the Location, expressed using the WGS84 datum (This is the same co-ordinate system used in KML).:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param float longitude: Longitude with WGS84 datum
    :param float latitude: Latitude with WGS84 datum
    :param float altitude: Altitude with WGS84 datum
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        longitude: "float" = None,
        latitude: "float" = None,
        altitude: "float" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.longitude = longitude
        self.latitude = latitude
        self.altitude = altitude

    @classmethod
    def from_dict(cls, data: dict) -> "Location":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Location":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Location(DomainResource):
    """Details and position information for a place where services are provided and resources and participants may be stored, found, contained, or accommodated.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Unique code or number identifying the location to its users
    :param str status: active | suspended | inactive
    :param Coding operationalStatus: The operational status of the location (typically only for a bed/room)
    :param str name: Name of the location as used by humans
    :param str alias: A list of alternate names that the location is known as, or was known as, in the past
    :param str description: Additional details about the location that could be displayed as further information to identify the location beyond its name
    :param str mode: instance | kind
    :param CodeableConcept type: Type of function performed
    :param ExtendedContactDetail contact: Official contact details for the location
    :param Address address: Physical location
    :param CodeableConcept form: Physical form of the location
    :param Position position: The absolute geographic location
    :param Reference managingOrganization: Organization responsible for provisioning and upkeep
    :param Reference partOf: Another Location this one is physically a part of
    :param CodeableConcept characteristic: Collection of characteristics (attributes)
    :param Availability hoursOfOperation: What days/times during a week is this location usually open (including exceptions)
    :param VirtualServiceDetail virtualService: Connection details of a virtual service (e.g. conference call)
    :param Reference endpoint: Technical endpoints providing access to services operated for the location
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "operationalStatus": {"class_name": "Coding", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "contact": {"class_name": "ExtendedContactDetail", "is_contained": False},
        "address": {"class_name": "Address", "is_contained": False},
        "form": {"class_name": "CodeableConcept", "is_contained": False},
        "position": {"class_name": "Position", "is_contained": True},
        "managingOrganization": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "characteristic": {"class_name": "CodeableConcept", "is_contained": False},
        "hoursOfOperation": {"class_name": "Availability", "is_contained": False},
        "virtualService": {"class_name": "VirtualServiceDetail", "is_contained": False},
        "endpoint": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        status: "str" = None,
        operationalStatus: "Coding" = None,
        name: "str" = None,
        alias: list["str"] = None,
        description: "str" = None,
        mode: "str" = None,
        type: list["CodeableConcept"] = None,
        contact: list["ExtendedContactDetail"] = None,
        address: "Address" = None,
        form: "CodeableConcept" = None,
        position: "Position" = None,
        managingOrganization: "Reference" = None,
        partOf: "Reference" = None,
        characteristic: list["CodeableConcept"] = None,
        hoursOfOperation: list["Availability"] = None,
        virtualService: list["VirtualServiceDetail"] = None,
        endpoint: list["Reference"] = None,
    ):

        self.resourceType = "Location"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.status = status
        self.operationalStatus = operationalStatus
        self.name = name
        self.alias = alias or []
        self.description = description
        self.mode = mode
        self.type = type or []
        self.contact = contact or []
        self.address = address
        self.form = form
        self.position = position
        self.managingOrganization = managingOrganization
        self.partOf = partOf
        self.characteristic = characteristic or []
        self.hoursOfOperation = hoursOfOperation or []
        self.virtualService = virtualService or []
        self.endpoint = endpoint or []

    @classmethod
    def from_dict(cls, data: dict) -> "Location":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Location":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for TestPlan. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.CodeableReference import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.ContactDetail import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Identifier import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *
from fhirmodels.R5.UsageContext import *


class Dependency(FhirBaseModel):
    """The required criteria to execute the test plan - e.g. preconditions, previous tests...:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of the dependency criterium
    :param Reference predecessor: Link to predecessor test plans
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "predecessor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        predecessor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.predecessor = predecessor

    @classmethod
    def from_dict(cls, data: dict) -> "TestPlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestPlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Dependency(FhirBaseModel):
    """The required criteria to execute the test case - e.g. preconditions, previous tests.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str description: Description of the criteria
    :param Reference predecessor: Link to predecessor test plans
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "predecessor": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        description: "str" = None,
        predecessor: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.description = description
        self.predecessor = predecessor

    @classmethod
    def from_dict(cls, data: dict) -> "TestPlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestPlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Script(FhirBaseModel):
    """The test cases in a structured language e.g. gherkin, Postman, or FHIR TestScript.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept language: The language for the test cases e.g. 'gherkin', 'testscript'
    :param str sourceString: The actual content of the cases - references to TestScripts or externally defined content
    :param Reference sourceReference: The actual content of the cases - references to TestScripts or externally defined content
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "language": {"class_name": "CodeableConcept", "is_contained": False},
        "sourceReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        language: "CodeableConcept" = None,
        sourceString: "str" = None,
        sourceReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.language = language
        self.sourceString = sourceString
        self.sourceReference = sourceReference

    @classmethod
    def from_dict(cls, data: dict) -> "TestPlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestPlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class TestRun(FhirBaseModel):
    """The actual test to be executed.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str narrative: The narrative description of the tests
    :param Script script: The test cases in a structured language e.g. gherkin, Postman, or FHIR TestScript
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "script": {"class_name": "Script", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        narrative: "str" = None,
        script: "Script" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.narrative = narrative
        self.script = script

    @classmethod
    def from_dict(cls, data: dict) -> "TestPlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestPlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class TestData(FhirBaseModel):
    """The test data used in the test case.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Coding type: The type of test data description, e.g. 'synthea'
    :param Reference content: The actual test resources when they exist
    :param str sourceString: Pointer to a definition of test resources - narrative or structured e.g. synthetic data generation, etc
    :param Reference sourceReference: Pointer to a definition of test resources - narrative or structured e.g. synthetic data generation, etc
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "Coding", "is_contained": False},
        "content": {"class_name": "Reference", "is_contained": False},
        "sourceReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "Coding" = None,
        content: "Reference" = None,
        sourceString: "str" = None,
        sourceReference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.content = content
        self.sourceString = sourceString
        self.sourceReference = sourceReference

    @classmethod
    def from_dict(cls, data: dict) -> "TestPlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestPlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Assertion(FhirBaseModel):
    """The test assertions - the expectations of test results from the execution of the test case.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept type: Assertion type - for example 'informative' or 'required'
    :param CodeableReference object: The focus or object of the assertion
    :param CodeableReference result: The actual result assertion
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "object": {"class_name": "CodeableReference", "is_contained": False},
        "result": {"class_name": "CodeableReference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: list["CodeableConcept"] = None,
        object: list["CodeableReference"] = None,
        result: list["CodeableReference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type or []
        self.object = object or []
        self.result = result or []

    @classmethod
    def from_dict(cls, data: dict) -> "TestPlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestPlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class TestCase(FhirBaseModel):
    """The individual test cases that are part of this plan, when they they are made explicit.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param int sequence: Sequence of test case in the test plan
    :param Reference scope: The scope or artifact covered by the case
    :param Dependency dependency: Required criteria to execute the test case
    :param TestRun testRun: The actual test to be executed
    :param TestData testData: The test data used in the test case
    :param Assertion assertion: Test assertions or expectations
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "scope": {"class_name": "Reference", "is_contained": False},
        "dependency": {"class_name": "Dependency", "is_contained": True},
        "testRun": {"class_name": "TestRun", "is_contained": True},
        "testData": {"class_name": "TestData", "is_contained": True},
        "assertion": {"class_name": "Assertion", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        sequence: "int" = None,
        scope: list["Reference"] = None,
        dependency: list["Dependency"] = None,
        testRun: list["TestRun"] = None,
        testData: list["TestData"] = None,
        assertion: list["Assertion"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.sequence = sequence
        self.scope = scope or []
        self.dependency = dependency or []
        self.testRun = testRun or []
        self.testData = testData or []
        self.assertion = assertion or []

    @classmethod
    def from_dict(cls, data: dict) -> "TestPlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestPlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class TestPlan(DomainResource):
    """A plan for executing testing on an artifact or specifications
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str url: Canonical identifier for this test plan, represented as a URI (globally unique)
    :param Identifier identifier: Business identifier identifier for the test plan
    :param str version: Business version of the test plan
    :param str versionAlgorithmString: How to compare versions
    :param Coding versionAlgorithmCoding: How to compare versions
    :param str name: Name for this test plan (computer friendly)
    :param str title: Name for this test plan (human friendly)
    :param str status: draft | active | retired | unknown
    :param bool experimental: For testing purposes, not real usage
    :param str date: Date last changed
    :param str publisher: Name of the publisher/steward (organization or individual)
    :param ContactDetail contact: Contact details for the publisher
    :param str description: Natural language description of the test plan
    :param UsageContext useContext: The context that the content is intended to support
    :param CodeableConcept jurisdiction: Intended jurisdiction where the test plan applies (if applicable)
    :param str purpose: Why this test plan is defined
    :param str copyright: Use and/or publishing restrictions
    :param str copyrightLabel: Copyright holder and year(s)
    :param CodeableConcept category: The category of the Test Plan - can be acceptance, unit, performance
    :param Reference scope: What is being tested with this Test Plan - a conformance resource, or narrative criteria, or an external reference
    :param str testTools: A description of test tools to be used in the test plan - narrative for now
    :param Dependency dependency: The required criteria to execute the test plan - e.g. preconditions, previous tests
    :param str exitCriteria: The threshold or criteria for the test plan to be considered successfully executed - narrative
    :param TestCase testCase: The test cases that constitute this plan
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "versionAlgorithmCoding": {"class_name": "Coding", "is_contained": False},
        "contact": {"class_name": "ContactDetail", "is_contained": False},
        "useContext": {"class_name": "UsageContext", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "scope": {"class_name": "Reference", "is_contained": False},
        "dependency": {"class_name": "Dependency", "is_contained": True},
        "testCase": {"class_name": "TestCase", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        url: "str" = None,
        identifier: list["Identifier"] = None,
        version: "str" = None,
        versionAlgorithmString: "str" = None,
        versionAlgorithmCoding: "Coding" = None,
        name: "str" = None,
        title: "str" = None,
        status: "str" = None,
        experimental: "bool" = None,
        date: "str" = None,
        publisher: "str" = None,
        contact: list["ContactDetail"] = None,
        description: "str" = None,
        useContext: list["UsageContext"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        purpose: "str" = None,
        copyright: "str" = None,
        copyrightLabel: "str" = None,
        category: list["CodeableConcept"] = None,
        scope: list["Reference"] = None,
        testTools: "str" = None,
        dependency: list["Dependency"] = None,
        exitCriteria: "str" = None,
        testCase: list["TestCase"] = None,
    ):

        self.resourceType = "TestPlan"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.url = url
        self.identifier = identifier or []
        self.version = version
        self.versionAlgorithmString = versionAlgorithmString
        self.versionAlgorithmCoding = versionAlgorithmCoding
        self.name = name
        self.title = title
        self.status = status
        self.experimental = experimental
        self.date = date
        self.publisher = publisher
        self.contact = contact or []
        self.description = description
        self.useContext = useContext or []
        self.jurisdiction = jurisdiction or []
        self.purpose = purpose
        self.copyright = copyright
        self.copyrightLabel = copyrightLabel
        self.category = category or []
        self.scope = scope or []
        self.testTools = testTools
        self.dependency = dependency or []
        self.exitCriteria = exitCriteria
        self.testCase = testCase or []

    @classmethod
    def from_dict(cls, data: dict) -> "TestPlan":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "TestPlan":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ParticipantContactable. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Address import *
from fhirmodels.R5.ContactPoint import *


class ParticipantContactable(FhirBaseModel):
    """Logical Model: A pattern followed by resources that represent a participant that can be contacted.
    :param ContactPoint telecom: A contact detail for the {{title}}
    :param Address address: An address for the {{title}}
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "telecom": {"class_name": "ContactPoint", "is_contained": False},
        "address": {"class_name": "Address", "is_contained": False},
    }

    def __init__(
        self,
        telecom: list["ContactPoint"] = None,
        address: list["Address"] = None,
    ):

        self.telecom = telecom or []
        self.address = address or []

    @classmethod
    def from_dict(cls, data: dict) -> "ParticipantContactable":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ParticipantContactable":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SubstanceAmount. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.Element import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Range import *


class ReferenceRange(FhirBaseModel):
    """Reference range of possible or expected values.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Quantity lowLimit: Lower limit possible or expected
    :param Quantity highLimit: Upper limit possible or expected
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "lowLimit": {"class_name": "Quantity", "is_contained": False},
        "highLimit": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        lowLimit: "Quantity" = None,
        highLimit: "Quantity" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.lowLimit = lowLimit
        self.highLimit = highLimit

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceAmount":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceAmount":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class SubstanceAmount(FhirBaseModel):
    """Base StructureDefinition for SubstanceAmount Type: Chemical substances are a single substance type whose primary defining element is the molecular structure. Chemical substances shall be defined on the basis of their complete covalent molecular structure; the presence of a salt (counter-ion) and/or solvates (water, alcohols) is also captured. Purity, grade, physical form or particle size are not taken into account in the definition of a chemical substance or in the assignment of a Substance ID.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Quantity amountQuantity: Used to capture quantitative values for a variety of elements. If only limits are given, the arithmetic mean would be the average. If only a single definite value for a given element is given, it would be captured in this field
    :param Range amountRange: Used to capture quantitative values for a variety of elements. If only limits are given, the arithmetic mean would be the average. If only a single definite value for a given element is given, it would be captured in this field
    :param str amountString: Used to capture quantitative values for a variety of elements. If only limits are given, the arithmetic mean would be the average. If only a single definite value for a given element is given, it would be captured in this field
    :param CodeableConcept amountType: Most elements that require a quantitative value will also have a field called amount type. Amount type should always be specified because the actual value of the amount is often dependent on it. EXAMPLE: In capturing the actual relative amounts of substances or molecular fragments it is essential to indicate whether the amount refers to a mole ratio or weight ratio. For any given element an effort should be made to use same the amount type for all related definitional elements
    :param str amountText: A textual comment on a numeric value
    :param ReferenceRange referenceRange: Reference range of possible or expected values
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "amountQuantity": {"class_name": "Quantity", "is_contained": False},
        "amountRange": {"class_name": "Range", "is_contained": False},
        "amountType": {"class_name": "CodeableConcept", "is_contained": False},
        "referenceRange": {"class_name": "ReferenceRange", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        amountQuantity: "Quantity" = None,
        amountRange: "Range" = None,
        amountString: "str" = None,
        amountType: "CodeableConcept" = None,
        amountText: "str" = None,
        referenceRange: "ReferenceRange" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.amountQuantity = amountQuantity
        self.amountRange = amountRange
        self.amountString = amountString
        self.amountType = amountType
        self.amountText = amountText
        self.referenceRange = referenceRange

    @classmethod
    def from_dict(cls, data: dict) -> "SubstanceAmount":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SubstanceAmount":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for DeviceRequest. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Quantity import *
from fhirmodels.R4.Range import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *
from fhirmodels.R4.Timing import *


class Parameter(FhirBaseModel):
    """Specific parameters for the ordered item.  For example, the prism value for lenses.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept code: Device detail
    :param CodeableConcept valueCodeableConcept: Value of detail
    :param Quantity valueQuantity: Value of detail
    :param Range valueRange: Value of detail
    :param bool valueBoolean: Value of detail
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "valueCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "valueQuantity": {"class_name": "Quantity", "is_contained": False},
        "valueRange": {"class_name": "Range", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        code: "CodeableConcept" = None,
        valueCodeableConcept: "CodeableConcept" = None,
        valueQuantity: "Quantity" = None,
        valueRange: "Range" = None,
        valueBoolean: "bool" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.code = code
        self.valueCodeableConcept = valueCodeableConcept
        self.valueQuantity = valueQuantity
        self.valueRange = valueRange
        self.valueBoolean = valueBoolean

    @classmethod
    def from_dict(cls, data: dict) -> "DeviceRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DeviceRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class DeviceRequest(DomainResource):
    """Represents a request for a patient to employ a medical device. The device may be an implantable device, or an external assistive device, such as a walker.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: External Request identifier
    :param str instantiatesCanonical: Instantiates FHIR protocol or definition
    :param str instantiatesUri: Instantiates external protocol or definition
    :param Reference basedOn: What request fulfills
    :param Reference priorRequest: What request replaces
    :param Identifier groupIdentifier: Identifier of composite request
    :param str status: draft | active | on-hold | revoked | completed | entered-in-error | unknown
    :param str intent: proposal | plan | directive | order | original-order | reflex-order | filler-order | instance-order | option
    :param str priority: routine | urgent | asap | stat
    :param Reference codeReference: Device requested
    :param CodeableConcept codeCodeableConcept: Device requested
    :param Parameter parameter: Device details
    :param Reference subject: Focus of request
    :param Reference encounter: Encounter motivating request
    :param str occurrenceDateTime: Desired time or schedule for use
    :param Period occurrencePeriod: Desired time or schedule for use
    :param Timing occurrenceTiming: Desired time or schedule for use
    :param str authoredOn: When recorded
    :param Reference requester: Who/what is requesting diagnostics
    :param CodeableConcept performerType: Filler role
    :param Reference performer: Requested Filler
    :param CodeableConcept reasonCode: Coded Reason for request
    :param Reference reasonReference: Linked Reason for request
    :param Reference insurance: Associated insurance coverage
    :param Reference supportingInfo: Additional clinical information
    :param Annotation note: Notes or comments
    :param Reference relevantHistory: Request provenance
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "priorRequest": {"class_name": "Reference", "is_contained": False},
        "groupIdentifier": {"class_name": "Identifier", "is_contained": False},
        "codeReference": {"class_name": "Reference", "is_contained": False},
        "codeCodeableConcept": {"class_name": "CodeableConcept", "is_contained": False},
        "parameter": {"class_name": "Parameter", "is_contained": True},
        "subject": {"class_name": "Reference", "is_contained": False},
        "encounter": {"class_name": "Reference", "is_contained": False},
        "occurrencePeriod": {"class_name": "Period", "is_contained": False},
        "occurrenceTiming": {"class_name": "Timing", "is_contained": False},
        "requester": {"class_name": "Reference", "is_contained": False},
        "performerType": {"class_name": "CodeableConcept", "is_contained": False},
        "performer": {"class_name": "Reference", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "insurance": {"class_name": "Reference", "is_contained": False},
        "supportingInfo": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "relevantHistory": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        instantiatesCanonical: list["str"] = None,
        instantiatesUri: list["str"] = None,
        basedOn: list["Reference"] = None,
        priorRequest: list["Reference"] = None,
        groupIdentifier: "Identifier" = None,
        status: "str" = None,
        intent: "str" = None,
        priority: "str" = None,
        codeReference: "Reference" = None,
        codeCodeableConcept: "CodeableConcept" = None,
        parameter: list["Parameter"] = None,
        subject: "Reference" = None,
        encounter: "Reference" = None,
        occurrenceDateTime: "str" = None,
        occurrencePeriod: "Period" = None,
        occurrenceTiming: "Timing" = None,
        authoredOn: "str" = None,
        requester: "Reference" = None,
        performerType: "CodeableConcept" = None,
        performer: "Reference" = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        insurance: list["Reference"] = None,
        supportingInfo: list["Reference"] = None,
        note: list["Annotation"] = None,
        relevantHistory: list["Reference"] = None,
    ):

        self.resourceType = "DeviceRequest"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.instantiatesCanonical = instantiatesCanonical or []
        self.instantiatesUri = instantiatesUri or []
        self.basedOn = basedOn or []
        self.priorRequest = priorRequest or []
        self.groupIdentifier = groupIdentifier
        self.status = status
        self.intent = intent
        self.priority = priority
        self.codeReference = codeReference
        self.codeCodeableConcept = codeCodeableConcept
        self.parameter = parameter or []
        self.subject = subject
        self.encounter = encounter
        self.occurrenceDateTime = occurrenceDateTime
        self.occurrencePeriod = occurrencePeriod
        self.occurrenceTiming = occurrenceTiming
        self.authoredOn = authoredOn
        self.requester = requester
        self.performerType = performerType
        self.performer = performer
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.insurance = insurance or []
        self.supportingInfo = supportingInfo or []
        self.note = note or []
        self.relevantHistory = relevantHistory or []

    @classmethod
    def from_dict(cls, data: dict) -> "DeviceRequest":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "DeviceRequest":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for RelatedArtifact. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Attachment import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Reference import *


class RelatedArtifact(FhirBaseModel):
    """RelatedArtifact Type: Related artifacts such as additional documentation, justification, or bibliographic references.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str type: documentation | justification | citation | predecessor | successor | derived-from | depends-on | composed-of | part-of | amends | amended-with | appends | appended-with | cites | cited-by | comments-on | comment-in | contains | contained-in | corrects | correction-in | replaces | replaced-with | retracts | retracted-by | signs | similar-to | supports | supported-with | transforms | transformed-into | transformed-with | documents | specification-of | created-with | cite-as
    :param CodeableConcept classifier: Additional classifiers
    :param str label: Short label
    :param str display: Brief description of the related artifact
    :param str citation: Bibliographic citation for the artifact
    :param Attachment document: What document is being referenced
    :param str resource: What artifact is being referenced
    :param Reference resourceReference: What artifact, if not a conformance resource
    :param str publicationStatus: draft | active | retired | unknown
    :param str publicationDate: Date of publication of the artifact being referred to
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "classifier": {"class_name": "CodeableConcept", "is_contained": False},
        "document": {"class_name": "Attachment", "is_contained": False},
        "resourceReference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        type: "str" = None,
        classifier: list["CodeableConcept"] = None,
        label: "str" = None,
        display: "str" = None,
        citation: "str" = None,
        document: "Attachment" = None,
        resource: "str" = None,
        resourceReference: "Reference" = None,
        publicationStatus: "str" = None,
        publicationDate: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.type = type
        self.classifier = classifier or []
        self.label = label
        self.display = display
        self.citation = citation
        self.document = document
        self.resource = resource
        self.resourceReference = resourceReference
        self.publicationStatus = publicationStatus
        self.publicationDate = publicationDate

    @classmethod
    def from_dict(cls, data: dict) -> "RelatedArtifact":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "RelatedArtifact":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicationStatement. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.Annotation import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Dosage import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class MedicationStatement(DomainResource):
    """A record of a medication that is being consumed by a patient.   A MedicationStatement may indicate that the patient may be taking the medication now or has taken the medication in the past or will be taking the medication in the future.  The source of this information can be the patient, significant other (such as a family member or spouse), or a clinician.  A common scenario where this information is captured is during the history taking process during a patient visit or stay.   The medication information may come from sources such as the patient's memory, from a prescription bottle,  or from a list of medications the patient, clinician or other party maintains.

    The primary difference between a medication statement and a medication administration is that the medication administration has complete administration information and is based on actual administration information from the person who administered the medication.  A medication statement is often, if not always, less specific.  There is no required date/time when the medication was administered, in fact we only know that a source has reported the patient is taking this medication, where details such as time, quantity, or rate or even medication product may be incomplete or missing or less precise.  As stated earlier, the medication statement information may come from the patient's memory, from a prescription bottle or from a list of medications the patient, clinician or other party maintains.  Medication administration is more formal and is not missing detailed information.
        :param str id: Logical id of this artifact
        :param Meta meta: Metadata about the resource
        :param str implicitRules: A set of rules under which this content was created
        :param str language: Language of the resource content
        :param Narrative text: Text summary of the resource, for human interpretation
        :param Resource contained: Contained, inline Resources
        :param Extension extension: Additional content defined by implementations
        :param Extension modifierExtension: Extensions that cannot be ignored
        :param Identifier identifier: External identifier
        :param Reference basedOn: Fulfils plan, proposal or order
        :param Reference partOf: Part of referenced event
        :param str status: active | completed | entered-in-error | intended | stopped | on-hold | unknown | not-taken
        :param CodeableConcept statusReason: Reason for current status
        :param CodeableConcept category: Type of medication usage
        :param CodeableConcept medicationCodeableConcept: What medication was taken
        :param Reference medicationReference: What medication was taken
        :param Reference subject: Who is/was taking  the medication
        :param Reference context: Encounter / Episode associated with MedicationStatement
        :param str effectiveDateTime: The date/time or interval when the medication is/was/will be taken
        :param Period effectivePeriod: The date/time or interval when the medication is/was/will be taken
        :param str dateAsserted: When the statement was asserted?
        :param Reference informationSource: Person or organization that provided the information about the taking of this medication
        :param Reference derivedFrom: Additional supporting information
        :param CodeableConcept reasonCode: Reason for why the medication is being/was taken
        :param Reference reasonReference: Condition or observation that supports why the medication is being/was taken
        :param Annotation note: Further information about the statement
        :param Dosage dosage: Details of how medication is/was taken or should be taken
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "basedOn": {"class_name": "Reference", "is_contained": False},
        "partOf": {"class_name": "Reference", "is_contained": False},
        "statusReason": {"class_name": "CodeableConcept", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "medicationCodeableConcept": {
            "class_name": "CodeableConcept",
            "is_contained": False,
        },
        "medicationReference": {"class_name": "Reference", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "context": {"class_name": "Reference", "is_contained": False},
        "effectivePeriod": {"class_name": "Period", "is_contained": False},
        "informationSource": {"class_name": "Reference", "is_contained": False},
        "derivedFrom": {"class_name": "Reference", "is_contained": False},
        "reasonCode": {"class_name": "CodeableConcept", "is_contained": False},
        "reasonReference": {"class_name": "Reference", "is_contained": False},
        "note": {"class_name": "Annotation", "is_contained": False},
        "dosage": {"class_name": "Dosage", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        basedOn: list["Reference"] = None,
        partOf: list["Reference"] = None,
        status: "str" = None,
        statusReason: list["CodeableConcept"] = None,
        category: "CodeableConcept" = None,
        medicationCodeableConcept: "CodeableConcept" = None,
        medicationReference: "Reference" = None,
        subject: "Reference" = None,
        context: "Reference" = None,
        effectiveDateTime: "str" = None,
        effectivePeriod: "Period" = None,
        dateAsserted: "str" = None,
        informationSource: "Reference" = None,
        derivedFrom: list["Reference"] = None,
        reasonCode: list["CodeableConcept"] = None,
        reasonReference: list["Reference"] = None,
        note: list["Annotation"] = None,
        dosage: list["Dosage"] = None,
    ):

        self.resourceType = "MedicationStatement"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.basedOn = basedOn or []
        self.partOf = partOf or []
        self.status = status
        self.statusReason = statusReason or []
        self.category = category
        self.medicationCodeableConcept = medicationCodeableConcept
        self.medicationReference = medicationReference
        self.subject = subject
        self.context = context
        self.effectiveDateTime = effectiveDateTime
        self.effectivePeriod = effectivePeriod
        self.dateAsserted = dateAsserted
        self.informationSource = informationSource
        self.derivedFrom = derivedFrom or []
        self.reasonCode = reasonCode or []
        self.reasonReference = reasonReference or []
        self.note = note or []
        self.dosage = dosage or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicationStatement":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicationStatement":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Meta. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Coding import *
from fhirmodels.R5.Extension import *


class Meta(FhirBaseModel):
    """Meta Type: The metadata about a resource. This is content in the resource that is maintained by the infrastructure. Changes to the content might not always be associated with version changes to the resource.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param str versionId: Version specific identifier
    :param str lastUpdated: When the resource version last changed
    :param str source: Identifies where the resource comes from
    :param str profile: Profiles this resource claims to conform to
    :param Coding security: Security Labels applied to this resource
    :param Coding tag: Tags applied to this resource
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "security": {"class_name": "Coding", "is_contained": False},
        "tag": {"class_name": "Coding", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        versionId: "str" = None,
        lastUpdated: "str" = None,
        source: "str" = None,
        profile: list["str"] = None,
        security: list["Coding"] = None,
        tag: list["Coding"] = None,
    ):

        self.id = id
        self.extension = extension or []
        self.versionId = versionId
        self.lastUpdated = lastUpdated
        self.source = source
        self.profile = profile or []
        self.security = security or []
        self.tag = tag or []

    @classmethod
    def from_dict(cls, data: dict) -> "Meta":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Meta":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for Permission. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.R5.BackboneElement import *
from fhirmodels.R5.CodeableConcept import *
from fhirmodels.R5.Coding import *
from fhirmodels.R5.DomainResource import *
from fhirmodels.R5.Expression import *
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Meta import *
from fhirmodels.R5.Narrative import *
from fhirmodels.R5.Period import *
from fhirmodels.R5.Reference import *
from fhirmodels.R5.Resource import *


class Justification(FhirBaseModel):
    """The asserted justification for using the data.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept basis: The regulatory grounds upon which this Permission builds
    :param Reference evidence: Justifing rational
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "basis": {"class_name": "CodeableConcept", "is_contained": False},
        "evidence": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        basis: list["CodeableConcept"] = None,
        evidence: list["Reference"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.basis = basis or []
        self.evidence = evidence or []

    @classmethod
    def from_dict(cls, data: dict) -> "Permission":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Permission":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Resource(FhirBaseModel):
    """Explicit FHIR Resource references.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str meaning: instance | related | dependents | authoredby
    :param Reference reference: The actual data reference
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "reference": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        meaning: "str" = None,
        reference: "Reference" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.meaning = meaning
        self.reference = reference

    @classmethod
    def from_dict(cls, data: dict) -> "Permission":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Permission":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Data(FhirBaseModel):
    """A description or definition of which activities are allowed to be done on the data.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Resource resource: Explicit FHIR Resource references
    :param Coding security: Security tag code on .meta.security
    :param Period period: Timeframe encompasing data create/update
    :param Expression expression: Expression identifying the data
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "resource": {"class_name": "Resource", "is_contained": True},
        "security": {"class_name": "Coding", "is_contained": False},
        "period": {"class_name": "Period", "is_contained": False},
        "expression": {"class_name": "Expression", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        resource: list["Resource"] = None,
        security: list["Coding"] = None,
        period: list["Period"] = None,
        expression: "Expression" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.resource = resource or []
        self.security = security or []
        self.period = period or []
        self.expression = expression

    @classmethod
    def from_dict(cls, data: dict) -> "Permission":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Permission":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Activity(FhirBaseModel):
    """A description or definition of which activities are allowed to be done on the data.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Reference actor: Authorized actor(s)
    :param CodeableConcept action: Actions controlled by this rule
    :param CodeableConcept purpose: The purpose for which the permission is given
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "actor": {"class_name": "Reference", "is_contained": False},
        "action": {"class_name": "CodeableConcept", "is_contained": False},
        "purpose": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        actor: list["Reference"] = None,
        action: list["CodeableConcept"] = None,
        purpose: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.actor = actor or []
        self.action = action or []
        self.purpose = purpose or []

    @classmethod
    def from_dict(cls, data: dict) -> "Permission":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Permission":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Rule(FhirBaseModel):
    """A set of rules.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str type: deny | permit
    :param Data data: The selection criteria to identify data that is within scope of this provision
    :param Activity activity: A description or definition of which activities are allowed to be done on the data
    :param CodeableConcept limit: What limits apply to the use of the data
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "data": {"class_name": "Data", "is_contained": True},
        "activity": {"class_name": "Activity", "is_contained": True},
        "limit": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        type: "str" = None,
        data: list["Data"] = None,
        activity: list["Activity"] = None,
        limit: list["CodeableConcept"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.type = type
        self.data = data or []
        self.activity = activity or []
        self.limit = limit or []

    @classmethod
    def from_dict(cls, data: dict) -> "Permission":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Permission":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Permission(DomainResource):
    """Permission resource holds access rules for a given data and context.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param str status: active | entered-in-error | draft | rejected
    :param Reference asserter: The person or entity that asserts the permission
    :param str date: The date that permission was asserted
    :param Period validity: The period in which the permission is active
    :param Justification justification: The asserted justification for using the data
    :param str combining: deny-overrides | permit-overrides | ordered-deny-overrides | ordered-permit-overrides | deny-unless-permit | permit-unless-deny
    :param Rule rule: Constraints to the Permission
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "asserter": {"class_name": "Reference", "is_contained": False},
        "validity": {"class_name": "Period", "is_contained": False},
        "justification": {"class_name": "Justification", "is_contained": True},
        "rule": {"class_name": "Rule", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        status: "str" = None,
        asserter: "Reference" = None,
        date: list["str"] = None,
        validity: "Period" = None,
        justification: "Justification" = None,
        combining: "str" = None,
        rule: list["Rule"] = None,
    ):

        self.resourceType = "Permission"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.status = status
        self.asserter = asserter
        self.date = date or []
        self.validity = validity
        self.justification = justification
        self.combining = combining
        self.rule = rule or []

    @classmethod
    def from_dict(cls, data: dict) -> "Permission":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "Permission":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for SampledData. 
Time: 2024-06-14 18:37:55
"""

from fhirmodels.generator import FhirBaseModel
from fhirmodels.R5.Extension import *
from fhirmodels.R5.Quantity import *


class SampledData(FhirBaseModel):
    """SampledData Type: A series of measurements taken by a device, with upper and lower limits. There may be more than one dimension in the data.
    :param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Quantity origin: Zero value and units
    :param float interval: Number of intervalUnits between samples
    :param str intervalUnit: The measurement unit of the interval between samples
    :param float factor: Multiply data by this before adding to origin
    :param float lowerLimit: Lower limit of detection
    :param float upperLimit: Upper limit of detection
    :param int dimensions: Number of sample points at each time point
    :param str codeMap: Defines the codes used in the data
    :param str offsets: Offsets, typically in time, at which data values were taken
    :param str data: Decimal values with spaces, or "E" | "U" | "L", or another code
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "origin": {"class_name": "Quantity", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        origin: "Quantity" = None,
        interval: "float" = None,
        intervalUnit: "str" = None,
        factor: "float" = None,
        lowerLimit: "float" = None,
        upperLimit: "float" = None,
        dimensions: "int" = None,
        codeMap: "str" = None,
        offsets: "str" = None,
        data: "str" = None,
    ):

        self.id = id
        self.extension = extension or []
        self.origin = origin
        self.interval = interval
        self.intervalUnit = intervalUnit
        self.factor = factor
        self.lowerLimit = lowerLimit
        self.upperLimit = upperLimit
        self.dimensions = dimensions
        self.codeMap = codeMap
        self.offsets = offsets
        self.data = data

    @classmethod
    def from_dict(cls, data: dict) -> "SampledData":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "SampledData":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for ObservationDefinition. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Range import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class QuantitativeDetails(FhirBaseModel):
    """Characteristics for quantitative results of this observation.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param CodeableConcept customaryUnit: Customary unit for quantitative results
    :param CodeableConcept unit: SI unit for quantitative results
    :param float conversionFactor: SI to Customary unit conversion factor
    :param int decimalPrecision: Decimal precision of observation quantitative results
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "customaryUnit": {"class_name": "CodeableConcept", "is_contained": False},
        "unit": {"class_name": "CodeableConcept", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        customaryUnit: "CodeableConcept" = None,
        unit: "CodeableConcept" = None,
        conversionFactor: "float" = None,
        decimalPrecision: "int" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.customaryUnit = customaryUnit
        self.unit = unit
        self.conversionFactor = conversionFactor
        self.decimalPrecision = decimalPrecision

    @classmethod
    def from_dict(cls, data: dict) -> "ObservationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ObservationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class QualifiedInterval(FhirBaseModel):
    """Multiple  ranges of results qualified by different contexts for ordinal or continuous observations conforming to this ObservationDefinition.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param str category: reference | critical | absolute
    :param Range range: The interval itself, for continuous or ordinal observations
    :param CodeableConcept context: Range context qualifier
    :param CodeableConcept appliesTo: Targetted population of the range
    :param str gender: male | female | other | unknown
    :param Range age: Applicable age range, if relevant
    :param Range gestationalAge: Applicable gestational age range, if relevant
    :param str condition: Condition associated with the reference range
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "range": {"class_name": "Range", "is_contained": False},
        "context": {"class_name": "CodeableConcept", "is_contained": False},
        "appliesTo": {"class_name": "CodeableConcept", "is_contained": False},
        "age": {"class_name": "Range", "is_contained": False},
        "gestationalAge": {"class_name": "Range", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: "str" = None,
        range: "Range" = None,
        context: "CodeableConcept" = None,
        appliesTo: list["CodeableConcept"] = None,
        gender: "str" = None,
        age: "Range" = None,
        gestationalAge: "Range" = None,
        condition: "str" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category
        self.range = range
        self.context = context
        self.appliesTo = appliesTo or []
        self.gender = gender
        self.age = age
        self.gestationalAge = gestationalAge
        self.condition = condition

    @classmethod
    def from_dict(cls, data: dict) -> "ObservationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ObservationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class ObservationDefinition(DomainResource):
    """Set of definitional characteristics for a kind of observation or measurement produced or consumed by an orderable health care service.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param CodeableConcept category: Category of observation
    :param CodeableConcept code: Type of observation (code / type)
    :param Identifier identifier: Business identifier for this ObservationDefinition instance
    :param str permittedDataType: Quantity | CodeableConcept | string | boolean | integer | Range | Ratio | SampledData | time | dateTime | Period
    :param bool multipleResultsAllowed: Multiple results allowed
    :param CodeableConcept method: Method used to produce the observation
    :param str preferredReportName: Preferred report name
    :param QuantitativeDetails quantitativeDetails: Characteristics of quantitative results
    :param QualifiedInterval qualifiedInterval: Qualified range for continuous and ordinal observation results
    :param Reference validCodedValueSet: Value set of valid coded values for the observations conforming to this ObservationDefinition
    :param Reference normalCodedValueSet: Value set of normal coded values for the observations conforming to this ObservationDefinition
    :param Reference abnormalCodedValueSet: Value set of abnormal coded values for the observations conforming to this ObservationDefinition
    :param Reference criticalCodedValueSet: Value set of critical coded values for the observations conforming to this ObservationDefinition
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "category": {"class_name": "CodeableConcept", "is_contained": False},
        "code": {"class_name": "CodeableConcept", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "method": {"class_name": "CodeableConcept", "is_contained": False},
        "quantitativeDetails": {
            "class_name": "QuantitativeDetails",
            "is_contained": True,
        },
        "qualifiedInterval": {"class_name": "QualifiedInterval", "is_contained": True},
        "validCodedValueSet": {"class_name": "Reference", "is_contained": False},
        "normalCodedValueSet": {"class_name": "Reference", "is_contained": False},
        "abnormalCodedValueSet": {"class_name": "Reference", "is_contained": False},
        "criticalCodedValueSet": {"class_name": "Reference", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        category: list["CodeableConcept"] = None,
        code: "CodeableConcept" = None,
        identifier: list["Identifier"] = None,
        permittedDataType: list["str"] = None,
        multipleResultsAllowed: "bool" = None,
        method: "CodeableConcept" = None,
        preferredReportName: "str" = None,
        quantitativeDetails: "QuantitativeDetails" = None,
        qualifiedInterval: list["QualifiedInterval"] = None,
        validCodedValueSet: "Reference" = None,
        normalCodedValueSet: "Reference" = None,
        abnormalCodedValueSet: "Reference" = None,
        criticalCodedValueSet: "Reference" = None,
    ):

        self.resourceType = "ObservationDefinition"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.category = category or []
        self.code = code
        self.identifier = identifier or []
        self.permittedDataType = permittedDataType or []
        self.multipleResultsAllowed = multipleResultsAllowed
        self.method = method
        self.preferredReportName = preferredReportName
        self.quantitativeDetails = quantitativeDetails
        self.qualifiedInterval = qualifiedInterval or []
        self.validCodedValueSet = validCodedValueSet
        self.normalCodedValueSet = normalCodedValueSet
        self.abnormalCodedValueSet = abnormalCodedValueSet
        self.criticalCodedValueSet = criticalCodedValueSet

    @classmethod
    def from_dict(cls, data: dict) -> "ObservationDefinition":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "ObservationDefinition":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()



"""
Generated class for MedicinalProductAuthorization. 
Time: 2024-06-14 18:37:17
"""

from fhirmodels.R4.BackboneElement import *
from fhirmodels.R4.CodeableConcept import *
from fhirmodels.R4.DomainResource import *
from fhirmodels.R4.Extension import *
from fhirmodels.R4.Identifier import *
from fhirmodels.R4.Meta import *
from fhirmodels.R4.Narrative import *
from fhirmodels.R4.Period import *
from fhirmodels.R4.Reference import *
from fhirmodels.R4.Resource import *


class JurisdictionalAuthorization(FhirBaseModel):
    """Authorization in areas within a country.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: The assigned number for the marketing authorization
    :param CodeableConcept country: Country of authorization
    :param CodeableConcept jurisdiction: Jurisdiction within a country
    :param CodeableConcept legalStatusOfSupply: The legal status of supply in a jurisdiction or region
    :param Period validityPeriod: The start and expected end date of the authorization
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "country": {"class_name": "CodeableConcept", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "legalStatusOfSupply": {"class_name": "CodeableConcept", "is_contained": False},
        "validityPeriod": {"class_name": "Period", "is_contained": False},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        country: "CodeableConcept" = None,
        jurisdiction: list["CodeableConcept"] = None,
        legalStatusOfSupply: "CodeableConcept" = None,
        validityPeriod: "Period" = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.country = country
        self.jurisdiction = jurisdiction or []
        self.legalStatusOfSupply = legalStatusOfSupply
        self.validityPeriod = validityPeriod

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductAuthorization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductAuthorization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class Procedure(FhirBaseModel):
    """The regulatory procedure for granting or amending a marketing authorization.:param str id: Unique id for inter-element referencing
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored even if unrecognized
    :param Identifier identifier: Identifier for this procedure
    :param CodeableConcept type: Type of procedure
    :param Period datePeriod: Date of procedure
    :param str dateDateTime: Date of procedure
    :param Application application: Applcations submitted to obtain a marketing authorization
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "type": {"class_name": "CodeableConcept", "is_contained": False},
        "datePeriod": {"class_name": "Period", "is_contained": False},
        "application": {"class_name": "Application", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: "Identifier" = None,
        type: "CodeableConcept" = None,
        datePeriod: "Period" = None,
        dateDateTime: "str" = None,
        application: list["Application"] = None,
    ):
        self.id = id
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier
        self.type = type
        self.datePeriod = datePeriod
        self.dateDateTime = dateDateTime
        self.application = application or []

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductAuthorization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductAuthorization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()


class MedicinalProductAuthorization(DomainResource):
    """The regulatory authorization of a medicinal product.
    :param str id: Logical id of this artifact
    :param Meta meta: Metadata about the resource
    :param str implicitRules: A set of rules under which this content was created
    :param str language: Language of the resource content
    :param Narrative text: Text summary of the resource, for human interpretation
    :param Resource contained: Contained, inline Resources
    :param Extension extension: Additional content defined by implementations
    :param Extension modifierExtension: Extensions that cannot be ignored
    :param Identifier identifier: Business identifier for the marketing authorization, as assigned by a regulator
    :param Reference subject: The medicinal product that is being authorized
    :param CodeableConcept country: The country in which the marketing authorization has been granted
    :param CodeableConcept jurisdiction: Jurisdiction within a country
    :param CodeableConcept status: The status of the marketing authorization
    :param str statusDate: The date at which the given status has become applicable
    :param str restoreDate: The date when a suspended the marketing or the marketing authorization of the product is anticipated to be restored
    :param Period validityPeriod: The beginning of the time period in which the marketing authorization is in the specific status shall be specified A complete date consisting of day, month and year shall be specified using the ISO 8601 date format
    :param Period dataExclusivityPeriod: A period of time after authorization before generic product applicatiosn can be submitted
    :param str dateOfFirstAuthorization: The date when the first authorization was granted by a Medicines Regulatory Agency
    :param str internationalBirthDate: Date of first marketing authorization for a company's new medicinal product in any country in the World
    :param CodeableConcept legalBasis: The legal framework against which this authorization is granted
    :param JurisdictionalAuthorization jurisdictionalAuthorization: Authorization in areas within a country
    :param Reference holder: Marketing Authorization Holder
    :param Reference regulator: Medicines Regulatory Agency
    :param Procedure procedure: The regulatory procedure for granting or amending a marketing authorization
    """

    # needed for complex properties where the element name is different from the class name
    property_class_info = {
        "meta": {"class_name": "Meta", "is_contained": False},
        "text": {"class_name": "Narrative", "is_contained": False},
        "contained": {"class_name": "Resource", "is_contained": False},
        "extension": {"class_name": "Extension", "is_contained": False},
        "modifierExtension": {"class_name": "Extension", "is_contained": False},
        "identifier": {"class_name": "Identifier", "is_contained": False},
        "subject": {"class_name": "Reference", "is_contained": False},
        "country": {"class_name": "CodeableConcept", "is_contained": False},
        "jurisdiction": {"class_name": "CodeableConcept", "is_contained": False},
        "status": {"class_name": "CodeableConcept", "is_contained": False},
        "validityPeriod": {"class_name": "Period", "is_contained": False},
        "dataExclusivityPeriod": {"class_name": "Period", "is_contained": False},
        "legalBasis": {"class_name": "CodeableConcept", "is_contained": False},
        "jurisdictionalAuthorization": {
            "class_name": "JurisdictionalAuthorization",
            "is_contained": True,
        },
        "holder": {"class_name": "Reference", "is_contained": False},
        "regulator": {"class_name": "Reference", "is_contained": False},
        "procedure": {"class_name": "Procedure", "is_contained": True},
    }

    def __init__(
        self,
        id: "str" = None,
        meta: "Meta" = None,
        implicitRules: "str" = None,
        language: "str" = None,
        text: "Narrative" = None,
        contained: list["Resource"] = None,
        extension: list["Extension"] = None,
        modifierExtension: list["Extension"] = None,
        identifier: list["Identifier"] = None,
        subject: "Reference" = None,
        country: list["CodeableConcept"] = None,
        jurisdiction: list["CodeableConcept"] = None,
        status: "CodeableConcept" = None,
        statusDate: "str" = None,
        restoreDate: "str" = None,
        validityPeriod: "Period" = None,
        dataExclusivityPeriod: "Period" = None,
        dateOfFirstAuthorization: "str" = None,
        internationalBirthDate: "str" = None,
        legalBasis: "CodeableConcept" = None,
        jurisdictionalAuthorization: list["JurisdictionalAuthorization"] = None,
        holder: "Reference" = None,
        regulator: "Reference" = None,
        procedure: "Procedure" = None,
    ):

        self.resourceType = "MedicinalProductAuthorization"

        self.id = id
        self.meta = meta
        self.implicitRules = implicitRules
        self.language = language
        self.text = text
        self.contained = contained or []
        self.extension = extension or []
        self.modifierExtension = modifierExtension or []
        self.identifier = identifier or []
        self.subject = subject
        self.country = country or []
        self.jurisdiction = jurisdiction or []
        self.status = status
        self.statusDate = statusDate
        self.restoreDate = restoreDate
        self.validityPeriod = validityPeriod
        self.dataExclusivityPeriod = dataExclusivityPeriod
        self.dateOfFirstAuthorization = dateOfFirstAuthorization
        self.internationalBirthDate = internationalBirthDate
        self.legalBasis = legalBasis
        self.jurisdictionalAuthorization = jurisdictionalAuthorization or []
        self.holder = holder
        self.regulator = regulator
        self.procedure = procedure

    @classmethod
    def from_dict(cls, data: dict) -> "MedicinalProductAuthorization":
        return super().from_dict(data)

    @classmethod
    def from_obj(self, obj: object) -> "MedicinalProductAuthorization":
        return super().from_obj(obj)

    def as_dict(self) -> dict:
        return super().as_dict()
